﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ServiceModel.DomainServices.Client;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media.Imaging;
using Infragistics;
using Infragistics.Collections;
using System.Linq;
using System.Collections.ObjectModel;
using VirtualCollectionTest.Web;

namespace VirtualCollectionTest
{
    public partial class MainPage : UserControl, INotifyPropertyChanged
    {
        DomainService1 _context = new DomainService1();

        private const int DefaultAnticipatedSize = 20;

        private readonly VirtualCollection<TestClass> _vc;

        /// <summary>
        /// Cached total items count filtered by criteria.
        /// </summary>
        private int? _cachedTotalCount;

        public MainPage()
        {
            InitializeComponent();

            DataContext = this;

            _vc = new VirtualCollection<TestClass>(DefaultAnticipatedSize, 10);


            _vc.ItemDataRequested += VcItemDataRequested;

            _vc.PageSize = 2;
            xamGrid.ItemsSource = _vc;
        }


        private void CleanVirtualCollection()
        {
            if (_vc != null)
            {
                _vc.Refresh();

                // Setting _vc.AnticipatedCount is temporal
                //TotalCount = DefaultAnticipatedSize;
                _vc.AnticipatedCount = DefaultAnticipatedSize;
            }
        }

        private int _startIndex;

        /// <summary>
        /// Fires when VirtualCollection requesting data
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void VcItemDataRequested(object sender, ItemDataRequestedEventArgs e)
        {
            //LoadingStarted();

            _startIndex = e.StartIndex;
            int itemsCount = e.ItemsCount;


            //var query = _context.GetTestClassQuery(_startIndex, itemsCount);
            //_context.Load(query, ItemsLoaded, null);


            _vc.LoadItems(e.StartIndex, TestCollection);
        }

        private void ItemsLoaded(LoadOperation<TestClass> lo)
        {
            _vc.AnticipatedCount = lo.Entities.Count();
            _vc.LoadItems(_startIndex, lo.Entities);
        }

        private List<TestClass> _testCollection = new List<TestClass>
                                                                      {
                                                                          new TestClass{Name = "123", Age=15},
                                                                          new TestClass{Name = "456", Age=15},
                                                                          new TestClass{Name = "789", Age=15},
                                                                          new TestClass{Name = "123", Age=15}
                                                                      };
        public List<TestClass> TestCollection
        {
            get { return _testCollection; }
        }

        #region INotifyPropertyChanged implementation

        public event PropertyChangedEventHandler PropertyChanged;

        private void RaisePropertyChanged(string property)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(property));
            }
        }

        #endregion
    }
}
